@@ -1,5 +1,5 @@
 use tibco_ems::admin::BridgeInfo;
-use tibco_ems::DestinationType;
+use tibco_ems::Destination;
 
 fn main() {
   let url = "tcp://localhost:7222";
@@ -10,10 +10,8 @@ fn main() {
   let session = connection.session().unwrap();
 
   let bridge = BridgeInfo{
-    source_type: DestinationType::Topic,
-    source_name: "test.t".to_string(),
-    target_type: DestinationType::Queue,
-    target_name: "test.q".to_string(),
+    source: Destination::Topic("test.t".to_string()),
+    target: Destination::Queue("test.q".to_string()),
     selector: None,
   };
   let result = tibco_ems::admin::delete_bridge(&session,&bridge);
