@@ -1,7 +1,5 @@
 use tibco_ems::Destination;
-use tibco_ems::DestinationType;
-use tibco_ems::{TextMessage, BytesMessage, MapMessage};
-use tibco_ems::MessageType;
+use tibco_ems::Message;
 
 fn main() {
   let url = "tcp://localhost:7222";
@@ -12,11 +10,9 @@ fn main() {
   {
     let session = connection.session().unwrap();
 
-    let destination = Destination{
-      destination_type: DestinationType::Queue,
-      destination_name: "myqueue".to_string(),
-    };
-    let consumer = session.queue_consumer(destination,Some("CUSTOM_HEADER_1='VALUE_1'".to_string())).unwrap();
+    let destination = Destination::Queue("myqueue".to_string());
+    
+    let consumer = session.queue_consumer(&destination, Some("CUSTOM_HEADER_1='VALUE_1'")).unwrap();
     
     println!("waiting 10 seconds for a message");
     let msg_result = consumer.receive_message(Some(10000));
@@ -25,20 +21,17 @@ fn main() {
       Ok(result_value) => {
         match result_value {
           Some(message) => {
-            match message.message_type {
-              MessageType::TextMessage =>{
+            match &message {
+              Message::TextMessage(text_message) =>{
                 println!("received text message");
-                let text_message = TextMessage::from(message);
                 println!("header: {:?}",text_message.header);
               },
-              MessageType::BytesMessage =>{
+              Message::BytesMessage(bytes_message) =>{
                 println!("received bytes message");
-                let bytes_message = BytesMessage::from(message);
                 println!("header: {:?}",bytes_message.header);
               },
-              MessageType::MapMessage =>{
+              Message::MapMessage(map_message) =>{
                 println!("received map message");
-                let map_message = MapMessage::from(message);
                 println!("header: {:?}",map_message.header);
               },
             }    
